@@ -3,19 +3,19 @@
 #include <malloc.h>
 #include <string.h>
 #include <ctype.h>
-#ifdef DMALLOC
-#include <dmalloc.h>
-#endif /* DMALLOC */
+#ifdef MEMWATCH
+#include "memwatch.h"
+#endif /* MEMWATCH */
 #include "extern.h"
 
 /* malloc wrapper with error checking */
-void *malloc_w(size_t size) {
+void *malloc_wrapper(size_t size) {
 	void *ptr;
 
 	ptr = malloc(size);
 
 	if (!ptr) {
-		fprintf(stderr, "malloc_w: couldn't allocate memory\n");
+		fprintf(stderr, "malloc_wrapper: couldn't allocate memory\n");
 		exit(EXIT_FAILURE);
 	}
 
@@ -23,13 +23,13 @@ void *malloc_w(size_t size) {
 }
 
 /* strdup wrapper with error checking */
-char *strdup_w(const char *s) {
+char *strdup_wrapper(const char *s) {
 	char *ptr;
 
 	ptr = strdup(s);
 
 	if (!ptr) {
-		fprintf(stderr, "strdup_w: couldn't allocate memory\n");
+		fprintf(stderr, "strdup_wrapper: couldn't allocate memory\n");
 		exit(EXIT_FAILURE);
 	}
 
@@ -93,7 +93,7 @@ char *strrev(char *str)
 */
 /* slightly modified */
 
-char *remove_crud(char *str)
+void remove_crud(char *str)
 {
       char *obuf, *nbuf;
 
@@ -107,5 +107,4 @@ char *remove_crud(char *str)
             }
             *nbuf = 0;
       }
-      return str;
 }
